@@ -17,7 +17,8 @@ class IDeclarativeOption(ABC):
         self.dop: 'DeclarativeOptionParser' = dop
         self.long_forms: List[str] = list(filter(lambda x: x.startswith('--'), flags))
         self.short_forms: List[str] = list(filter(lambda x: x.startswith('-') and not x.startswith('--'), flags))
-        self.id: str = self.long_forms[0].replace('-', '_').strip('_')
+        self.positionals: List[str] = list(filter(lambda x: not x.startswith('-'), flags))
+        self.id: str = self._idFromFlags()
         self.description: Optional[str] = description
         self.nargs: Optional[str] = None
         self.const: Optional[Any] = None
@@ -33,10 +34,27 @@ class IDeclarativeOption(ABC):
     def _bindToNamespace(self, args: argparse.Namespace) -> None:
         self._args = args
 
+    def _idFromFlags(self) -> str:
+        ido: str = ''
+        if len(self.positionals) > 0:
+            ido = self.positionals[0]
+        elif len(self.long_forms) > 0:
+            ido = self.long_forms[0]
+        else:
+            raise Exception('A "--long-form" or "positional"-form flag must be present.')
+        return ido.replace('-', '_').strip('_')
+
     def setNArgs(self, nargs: Optional[str]) -> IDeclarativeOption:
         self.nargs = nargs
         return self
 
+    def addPositional(self, val: str) -> IDeclarativeOption:
+        self.positionals.append(val)
+        return self
+    def rmPositional(self, val: str) -> IDeclarativeOption:
+        self.positionals.remove(val)
+        return self
+
     def addLongForm(self, val: str) -> IDeclarativeOption:
         self.long_forms.append(val)
         return self
@@ -77,6 +95,7 @@ class IDeclarativeOption(ABC):
 
     def add_to_argparser(self, argp: argparse.ArgumentParser) -> None:
         args: List[str] = []
+        args += self.positionals
         args += self.long_forms
         args += self.short_forms
         kwargs: Dict[str, Any] = {}
